@@ -518,13 +518,13 @@ def evaluate_model_single_recording_preloaded(preprocessing_queue,
     :param feature_list: List of all feature objects.
     :param model: Neural network model.
     :param output_semantics: List that defines what an output means.
-    :param recording: The handwritten recording.
+    :param recording: The handwritten recording in JSON format.
     """
     handwriting = HandwrittenData.HandwrittenData(recording)
     handwriting.preprocessing(preprocessing_queue)
     x = handwriting.feature_extraction(feature_list)
     import nntoolkit.evaluate
-    model_output = nntoolkit.evaluate.get_model_output(model, x)
+    model_output = nntoolkit.evaluate.get_model_output(model, [x])
     return nntoolkit.evaluate.get_results(model_output, output_semantics)
 
 
